Coverage report

File | class |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
repo_ctx / __init__.py | (no class) |  | 1 | 0 | 0 |  | 100%
repo_ctx / __main__.py | (no class) |  | 195 | 195 | 0 |  | 0%
repo_ctx / config.py | Config |  | 101 | 22 | 0 |  | 78%
repo_ctx / config.py | (no class) |  | 20 | 0 | 0 |  | 100%
repo_ctx / core.py | RepositoryContext |  | 119 | 119 | 0 |  | 0%
repo_ctx / core.py | (no class) |  | 18 | 18 | 0 |  | 0%
repo_ctx / gitlab_client.py | GitLabClient |  | 22 | 22 | 0 |  | 0%
repo_ctx / gitlab_client.py | (no class) |  | 14 | 14 | 0 |  | 0%
repo_ctx / mcp_server.py | (no class) |  | 106 | 106 | 0 |  | 0%
repo_ctx / models.py | Library |  | 0 | 0 | 0 |  | 100%
repo_ctx / models.py | Version |  | 0 | 0 | 0 |  | 100%
repo_ctx / models.py | Document |  | 0 | 0 | 0 |  | 100%
repo_ctx / models.py | SearchResult |  | 0 | 0 | 0 |  | 100%
repo_ctx / models.py | FuzzySearchResult |  | 0 | 0 | 0 |  | 100%
repo_ctx / models.py | (no class) |  | 41 | 0 | 0 |  | 100%
repo_ctx / parser.py | Parser |  | 33 | 0 | 0 |  | 100%
repo_ctx / parser.py | (no class) |  | 10 | 0 | 0 |  | 100%
repo_ctx / providers / __init__.py | (no class) |  | 11 | 0 | 0 |  | 100%
repo_ctx / providers / base.py | ProviderProject |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / base.py | ProviderFile |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / base.py | GitProvider |  | 7 | 7 | 0 |  | 0%
repo_ctx / providers / base.py | (no class) |  | 31 | 0 | 0 |  | 100%
repo_ctx / providers / detector.py | ProviderDetector |  | 33 | 3 | 0 |  | 91%
repo_ctx / providers / detector.py | (no class) |  | 10 | 0 | 0 |  | 100%
repo_ctx / providers / exceptions.py | ProviderError |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / exceptions.py | ProviderNotFoundError |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / exceptions.py | ProviderAuthError |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / exceptions.py | ProviderFileNotFoundError |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / exceptions.py | ProviderRateLimitError |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / exceptions.py | ProviderConfigError |  | 0 | 0 | 0 |  | 100%
repo_ctx / providers / exceptions.py | (no class) |  | 12 | 0 | 0 |  | 100%
repo_ctx / providers / factory.py | ProviderFactory |  | 25 | 14 | 0 |  | 44%
repo_ctx / providers / factory.py | (no class) |  | 21 | 0 | 0 |  | 100%
repo_ctx / providers / github.py | GitHubProvider |  | 119 | 119 | 0 |  | 0%
repo_ctx / providers / github.py | (no class) |  | 15 | 0 | 0 |  | 100%
repo_ctx / providers / gitlab.py | GitLabProvider |  | 96 | 96 | 0 |  | 0%
repo_ctx / providers / gitlab.py | (no class) |  | 15 | 0 | 0 |  | 100%
repo_ctx / providers / local.py | LocalGitProvider |  | 107 | 23 | 0 |  | 79%
repo_ctx / providers / local.py | (no class) |  | 26 | 0 | 0 |  | 100%
repo_ctx / storage.py | Storage |  | 95 | 8 | 0 |  | 92%
repo_ctx / storage.py | (no class) |  | 31 | 0 | 0 |  | 100%
Total |  |  | 1334 | 766 | 0 |  | 43%

No items found using the specified filter.